==> ultra-erp-clean-v2.1.zip: src/Views/catalog/customers/index.php <==
<h5>Mijozlar</h5>
<div class="mb-2 d-flex gap-2">
  <button class="btn btn-primary btn-sm" data-bs-toggle="modal" data-bs-target="#cNew"><i class="bi bi-plus"></i> Yangi mijoz</button>
</div>
<table class="table table-sm table-hover"><thead><tr><th>Kod</th><th>Nomi</th><th>Tel</th><th>Region</th><th>Segment</th><th>GPS</th><th></th></tr></thead><tbody>
<?php foreach($rows as $r): ?><tr>
  <td><?=$r['code']?></td>
  <td><img src="<?=$r['avatar_url']?:('https://api.dicebear.com/7.x/initials/svg?seed='.urlencode($r['name']))?>" width="24" height="24" class="me-1"><?=$r['name']?></td>
  <td><?=$r['phone']?></td><td><?=$r['region']?></td><td><?=$r['segment']?></td><td><?=$r['gps_lat']?>,<?=$r['gps_lng']?></td>
  <td class="text-end">
    <button class="btn btn-outline-secondary btn-sm"
      data-bs-toggle="modal" data-bs-target="#cEdit"
      data-id="<?=$r['id']?>" data-code="<?=$r['code']?>" data-name="<?=$r['name']?>"
      data-phone="<?=$r['phone']?>" data-email="<?=$r['email']?>" data-region="<?=$r['region']?>"
      data-segment="<?=$r['segment']?>" data-type="<?=$r['type']?>" data-lat="<?=$r['gps_lat']?>" data-lng="<?=$r['gps_lng']?>" data-avatar="<?=$r['avatar_url']?>">Tahrirlash</button>
    <form method="post" action="?r=catalog/customers/delete" onsubmit="return confirm('O‘chirish?')" class="d-inline">
      <input type="hidden" name="id" value="<?=$r['id']?>"><button class="btn btn-outline-danger btn-sm"><i class="bi bi-trash"></i></button>
    </form>
  </td>
</tr><?php endforeach; ?></tbody></table>

<!-- New -->
<div class="modal fade" id="cNew" tabindex="-1"><div class="modal-dialog modal-lg"><div class="modal-content">
<div class="modal-header py-2"><h6>Yangi mijoz</h6><button class="btn-close" data-bs-dismiss="modal"></button></div>
<form method="post" action="?r=catalog/customers/create"><div class="modal-body">
<div class="row g-2">
  <div class="col-md-4"><label class="form-label">Kod</label><input class="form-control form-control-sm" name="code" required></div>
  <div class="col-md-8"><label class="form-label">Nomi</label><input class="form-control form-control-sm" name="name" required></div>
  <div class="col-md-4"><label class="form-label">Telefon</label><input class="form-control form-control-sm" name="phone"></div>
  <div class="col-md-4"><label class="form-label">Email</label><input class="form-control form-control-sm" name="email"></div>
  <div class="col-md-4"><label class="form-label">Rasm (URL)</label><input class="form-control form-control-sm" name="avatar_url" placeholder="https://..."></div>
  <div class="col-md-4"><label class="form-label">Region</label><input class="form-control form-control-sm" name="region"></div>
  <div class="col-md-4"><label class="form-label">Segment</label><input class="form-control form-control-sm" name="segment"></div>
  <div class="col-md-4"><label class="form-label">Turi</label><input class="form-control form-control-sm" name="type"></div>
  <div class="col-md-4"><label class="form-label">GPS Lat</label><input class="form-control form-control-sm" name="gps_lat"></div>
  <div class="col-md-4"><label class="form-label">GPS Lng</label><input class="form-control form-control-sm" name="gps_lng"></div>
</div>
</div><div class="modal-footer py-2"><button class="btn btn-secondary" data-bs-dismiss="modal">Yopish</button><button class="btn btn-primary">Saqlash</button></div></form>
</div></div></div>

<!-- Edit -->
<div class="modal fade" id="cEdit" tabindex="-1"><div class="modal-dialog modal-lg"><div class="modal-content">
<div class="modal-header py-2"><h6>Mijozni tahrirlash</h6><button class="btn-close" data-bs-dismiss="modal"></button></div>
<form method="post" action="?r=catalog/customers/update"><div class="modal-body">
<input type="hidden" name="id" id="e_id">
<div class="row g-2">
  <div class="col-md-4"><label class="form-label">Kod</label><input class="form-control form-control-sm" name="code" id="e_code" required></div>
  <div class="col-md-8"><label class="form-label">Nomi</label><input class="form-control form-control-sm" name="name" id="e_name" required></div>
  <div class="col-md-4"><label class="form-label">Telefon</label><input class="form-control form-control-sm" name="phone" id="e_phone"></div>
  <div class="col-md-4"><label class="form-label">Email</label><input class="form-control form-control-sm" name="email" id="e_email"></div>
  <div class="col-md-4"><label class="form-label">Rasm (URL)</label><input class="form-control form-control-sm" name="avatar_url" id="e_avatar"></div>
  <div class="col-md-4"><label class="form-label">Region</label><input class="form-control form-control-sm" name="region" id="e_region"></div>
  <div class="col-md-4"><label class="form-label">Segment</label><input class="form-control form-control-sm" name="segment" id="e_segment"></div>
  <div class="col-md-4"><label class="form-label">Turi</label><input class="form-control form-control-sm" name="type" id="e_type"></div>
  <div class="col-md-4"><label class="form-label">GPS Lat</label><input class="form-control form-control-sm" name="gps_lat" id="e_lat"></div>
  <div class="col-md-4"><label class="form-label">GPS Lng</label><input class="form-control form-control-sm" name="gps_lng" id="e_lng"></div>
</div>
</div><div class="modal-footer py-2"><button class="btn btn-secondary" data-bs-dismiss="modal">Yopish</button><button class="btn btn-primary">Saqlash</button></div></form>
</div></div></div>
<script>
document.getElementById('cEdit').addEventListener('show.bs.modal', function (ev){
  const b = ev.relatedTarget;
  e_id.value=b.dataset.id; e_code.value=b.dataset.code; e_name.value=b.dataset.name;
  e_phone.value=b.dataset.phone; e_email.value=b.dataset.email; e_region.value=b.dataset.region;
  e_segment.value=b.dataset.segment; e_type.value=b.dataset.type;
  e_lat.value=b.dataset.lat; e_lng.value=b.dataset.lng; e_avatar.value=b.dataset.avatar;
});
</script>

==> ultra-erp-clean-v2.2.zip: src/Views/catalog/customers/index.php <==
<h5>Mijozlar</h5>
<button class="btn btn-primary btn-sm mb-2" data-bs-toggle="modal" data-bs-target="#cNew"><i class="bi bi-plus"></i> Yangi mijoz</button>
<table class="table table-sm table-hover"><thead><tr><th>Kod</th><th>Nomi</th><th>Tel</th><th>Region</th><th>Segment</th><th>GPS</th><th></th></tr></thead><tbody>
<?php foreach($rows as $r): ?><tr>
  <td><?=$r['code']?></td><td><img src="<?=$r['avatar_url']?:('https://api.dicebear.com/7.x/initials/svg?seed='.urlencode($r['name']))?>" width="24" height="24" class="me-1"><?=$r['name']?></td>
  <td><?=$r['phone']?></td><td><?=$r['region']?></td><td><?=$r['segment']?></td><td><?=$r['gps_lat']?>,<?=$r['gps_lng']?></td>
  <td class="text-end"><form method="post" action="<?= \App\Core\Response::url(\'\1\') ?>" onsubmit="return confirm('O‘chirish?')" class="d-inline"><input type="hidden" name="id" value="<?=$r['id']?>"><button class="btn btn-outline-danger btn-sm"><i class="bi bi-trash"></i></button></form></td>
</tr><?php endforeach; ?></tbody></table>

<div class="modal fade" id="cNew" tabindex="-1"><div class="modal-dialog modal-lg"><div class="modal-content">
<div class="modal-header py-2"><h6>Yangi mijoz</h6><button class="btn-close" data-bs-dismiss="modal"></button></div>
<form method="post" action="<?= \App\Core\Response::url(\'\1\') ?>"><div class="modal-body">
<div class="row g-2">
  <div class="col-md-4"><label class="form-label">Kod</label><input class="form-control form-control-sm" name="code" required></div>
  <div class="col-md-8"><label class="form-label">Nomi</label><input class="form-control form-control-sm" name="name" required></div>
  <div class="col-md-4"><label class="form-label">Telefon</label><input class="form-control form-control-sm" name="phone"></div>
  <div class="col-md-4"><label class="form-label">Email</label><input class="form-control form-control-sm" name="email"></div>
  <div class="col-md-4"><label class="form-label">Rasm (URL)</label><input class="form-control form-control-sm" name="avatar_url" placeholder="https://..."></div>
  <div class="col-md-4"><label class="form-label">Region</label><input class="form-control form-control-sm" name="region"></div>
  <div class="col-md-4"><label class="form-label">Segment</label><input class="form-control form-control-sm" name="segment"></div>
  <div class="col-md-4"><label class="form-label">Turi</label><input class="form-control form-control-sm" name="type"></div>
  <div class="col-md-4"><label class="form-label">GPS Lat</label><input class="form-control form-control-sm" name="gps_lat"></div>
  <div class="col-md-4"><label class="form-label">GPS Lng</label><input class="form-control form-control-sm" name="gps_lng"></div>
</div>
</div><div class="modal-footer py-2"><button class="btn btn-secondary" data-bs-dismiss="modal">Yopish</button><button class="btn btn-primary">Saqlash</button></div></form>
</div></div></div>
